@@ -32,11 +32,5 @@ namespace PyBinding.Gui
 {
 	public class PythonEditorOutline : ClassOutlineTextEditorExtension
 	{
-		public override bool ExtendsEditor (Document doc, IEditableTextBuffer editor)
-		{
-			PythonLanguageBinding binding = MonoDevelop.Projects.LanguageBindingService.GetBindingPerFileName (doc.Name)
-				as PythonLanguageBinding;
-			return binding != null;
-		}
 	}
 }
